# model: iri_liver
Autogenerated ODE System from SBML file with sbmlutils.
```
time: [min]
substance: [mmol]
extent: [mmol]
volume: [l]
area: [m^2]
length: [m]
```

## Parameters `p`
```
ATPU_Km_atp = 0.01  # [mmol/l] 
ATPU_Vmax = 0.1  # [mmol/min/l] 
GLC2PYR_Ki_atp = 1.5  # [mmol/l] 
GLC2PYR_Km_adp = 0.01  # [mmol/l] 
GLC2PYR_Km_glc = 0.5  # [mmol/l] 
GLC2PYR_Vmax = 0.2  # [mmol/min/l] 
GLC2PYR_n_atp = 4.0  # [-] 
GLCIM_Km_glc = 0.1  # [mmol/l] 
GLCIM_Vmax = 100.0  # [mmol/min/l] 
LACEX_Km_lac = 0.5  # [mmol/l] 
LACEX_Vmax = 100.0  # [mmol/min/l] 
LDH_Ka_nadh = 0.1  # [mmol/l] 
LDH_Keq = 1.5  # [-] 
LDH_Km_lac = 1.0  # [mmol/l] 
LDH_Km_pyr = 1.0  # [mmol/l] 
LDH_Vmax = 1.0  # [mmol/min/l] 
O2IM_Km_o2 = 0.1  # [mmol/l] 
O2IM_Vmax = 100.0  # [mmol/min/l] 
OXPHOS_Km_adp = 0.05  # [mmol/l] 
OXPHOS_Km_nadh = 0.05  # [mmol/l] 
OXPHOS_Km_o2 = 0.05  # [mmol/l] 
OXPHOS_Vmax = 0.03  # [mmol/min/l] 
PROTEINR_k = 0.2  # [1/min] 
R = 8.314  # [kg*m^2/s^2/mol/K] 
ROSP_Vmax = 0.005  # [mmol/min/l] 
TCA_Km_nad = 0.01  # [mmol/l] 
TCA_Km_pyr = 0.1  # [mmol/l] 
TCA_Vmax = 0.01  # [mmol/min/l] 
Vext = 0.1  # [l] 
Vli = 1.5  # [l] 
Vmem = 1.0  # [m^2] 
cf_dimensionless = 1.0  # [1/mmol] 
f_Ea = 12.0  # [-] 
f_scale = 2.0  # [-] 
necrosis_atp_threshold = 0.1  # [mmol/l] 
ros_o2_threshold = 0.1  # [mmol/l] 
temperature = 310.15  # [K] 
temperature_ref = 310.15  # [K] 
```

## Initial conditions `x0`
```
adp = 1.0  # [mmol/l] Vli
alt = 1.0  # [mmol/l] Vli
alt_ext = 0.0  # [mmol/l] Vext
ast = 0.7  # [mmol/l] Vli
ast_ext = 0.0  # [mmol/l] Vext
atp = 3.0  # [mmol/l] Vli
glc = 5.0  # [mmol/l] Vli
glc_ext = 5.0  # [mmol/l] Vext
lac = 1.0  # [mmol/l] Vli
lac_ext = 1.0  # [mmol/l] Vext
nad = 0.1  # [mmol/l] Vli
nadh = 3.9  # [mmol/l] Vli
o2 = 1.2  # [mmol/l] Vli
o2_ext = 1.2  # [mmol/l] Vext
pyr = 0.8  # [mmol/l] Vli
ros = 0.0  # [mmol/l] Vli
tsim = 0.0  # [min] 
```

## ODE system
```
# y
f_temperature = f_scale * exp(-(f_Ea * R * temperature_ref) / (R * temperature)) / exp(-(f_Ea * R * temperature_ref) / (R * temperature_ref))  # [-]
necrosis = piecewise(1, atp < necrosis_atp_threshold, 0)  # []
ALTR = f_temperature * necrosis * Vli * PROTEINR_k * alt  # [mmol/min]
ASTR = f_temperature * necrosis * Vli * PROTEINR_k * ast  # [mmol/min]
ATPU = f_temperature * Vli * ATPU_Vmax * atp / (ATPU_Km_atp + atp)  # [mmol/min]
GLC2PYR = (f_temperature * (1 - necrosis) * Vli * (GLC2PYR_Ki_atp / atp)**GLC2PYR_n_atp * GLC2PYR_Vmax * glc / (glc + GLC2PYR_Km_glc)) * adp / (adp + GLC2PYR_Km_adp)  # [mmol/min]
GLCIM = (f_temperature * (1 - necrosis) * Vli * GLCIM_Vmax / GLCIM_Km_glc) * (glc_ext - glc) / (1 + glc_ext / GLCIM_Km_glc + glc / GLCIM_Km_glc)  # [mmol/min]
LACEX = (f_temperature * (1 - necrosis) * Vli * LACEX_Vmax / LACEX_Km_lac) * (lac - lac_ext) / (1 + lac_ext / LACEX_Km_lac + lac / LACEX_Km_lac)  # [mmol/min]
LDH = (f_temperature * (1 - necrosis) * Vli * LDH_Vmax / LDH_Km_pyr) * (1 + nadh / LDH_Ka_nadh) * (pyr - lac / LDH_Keq) / (1 + pyr / LDH_Km_pyr + lac / LDH_Km_lac)  # [mmol/min]
O2IM = (f_temperature * (1 - necrosis) * Vli * O2IM_Vmax / O2IM_Km_o2) * (o2_ext - o2) / (1 + o2_ext / O2IM_Km_o2 + o2 / O2IM_Km_o2)  # [mmol/min]
OXPHOS = ((f_temperature * (1 - necrosis) * Vli * OXPHOS_Vmax * nadh / (nadh + OXPHOS_Km_nadh)) * o2 / (o2 + OXPHOS_Km_o2)) * adp / (adp + OXPHOS_Km_adp)  # [mmol/min]
ROSD = f_temperature * (1 - necrosis) * Vli * ROSP_Vmax * ros / ros_o2_threshold  # [mmol/min]
ROSP = (f_temperature * (1 - necrosis) * Vli * ROSP_Vmax * nadh / (nadh + OXPHOS_Km_nadh)) * piecewise(1, o2 < ros_o2_threshold, 0)  # [mmol/min]
TCA = (f_temperature * (1 - necrosis) * Vli * TCA_Vmax * pyr / (pyr + TCA_Km_pyr)) * nad / (nad + TCA_Km_nad)  # [mmol/min]

# odes
d adp/dt = -2 * GLC2PYR / Vli + ATPU / Vli - 3 * OXPHOS / Vli  # [mmol/l/min]
d alt/dt = -ALTR / Vli  # [mmol/l/min]
d alt_ext/dt = ALTR / Vext  # [mmol/l/min]
d ast/dt = -ASTR / Vli  # [mmol/l/min]
d ast_ext/dt = ASTR / Vext  # [mmol/l/min]
d atp/dt = (2 * GLC2PYR / Vli - ATPU / Vli) + 3 * OXPHOS / Vli  # [mmol/l/min]
d glc/dt = GLCIM / Vli - GLC2PYR / Vli  # [mmol/l/min]
d glc_ext/dt = -GLCIM / Vext  # [mmol/l/min]
d lac/dt = -LACEX / Vli + LDH / Vli  # [mmol/l/min]
d lac_ext/dt = LACEX / Vext  # [mmol/l/min]
d nad/dt = -6 * TCA / Vli + OXPHOS / Vli  # [mmol/l/min]
d nadh/dt = 6 * TCA / Vli - OXPHOS / Vli  # [mmol/l/min]
d o2/dt = O2IM / Vli - 0.5 * OXPHOS / Vli  # [mmol/l/min]
d o2_ext/dt = -O2IM / Vext  # [mmol/l/min]
d pyr/dt = GLC2PYR / Vli - LDH / Vli - TCA / Vli  # [mmol/l/min]
d ros/dt = ROSP / Vli - ROSD / Vli  # [mmol/l/min]
d tsim/dt = 1  # [min/min]
```